<?php
/**
 * EU VAT for WooCommerce - General Section Settings
 *
 * @version 1.0.0
 * @since   1.0.0
 * @author  Algoritmika Ltd.
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'Alg_WC_EU_VAT_Settings_General' ) ) :

class Alg_WC_EU_VAT_Settings_General extends Alg_WC_EU_VAT_Settings_Section {

	/**
	 * Constructor.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function __construct() {
		$this->id   = '';
		$this->desc = __( 'General', 'eu-vat-for-woocommerce' );
		parent::__construct();
	}

	/**
	 * add_settings.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 * @todo    (dev) check if `clear` is still working (and if yes - change desc)
	 * @todo    (dev) `alg_wc_eu_vat_display_position`: maybe set default to `in_billing_address` instead of `after_order_table`
	 * @todo    (dev) (maybe) change "CSS class" to "Alignment"
	 * @todo    (dev) (maybe) set default value for "alg_wc_eu_vat_add_progress_text" to "yes"
	 * @todo    (feature) "Require Country Code in VAT Number"
	 * @todo    (feature) Message if customer is in base country and VAT is NOT exempted.
	 * @todo    (feature) Message if customer\'s check for IP location country has failed.
	 * @todo    (feature) (maybe) option to change default meta key
	 */
	function add_settings( $settings ) {

		$plugin_settings = array(
			array(
				'title'    => __( 'EU VAT Options', 'eu-vat-for-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_eu_vat_plugin_options',
				'desc'     => sprintf( __( 'Field ID used for EU VAT is %s.', 'eu-vat-for-woocommerce' ) , '<code>' . '_' . alg_wc_eu_vat_get_field_id() . '</code>' ) . ' ' .
					sprintf( __( 'Tool for adding EU country standard VAT rates: %s.', 'eu-vat-for-woocommerce' ),
						'<a href="' . admin_url( 'tools.php?page=alg-wc-eu-vat-country-rates' ) . '">' . __( 'Tools > EU country VAT Rates', 'eu-vat-for-woocommerce' ) . '</a>' ),
			),
			array(
				'title'    => __( 'EU VAT for WooCommerce', 'eu-vat-for-woocommerce' ),
				'desc'     => '<strong>' . __( 'Enable plugin', 'eu-vat-for-woocommerce' ) . '</strong>',
				'desc_tip' => __( 'Manage EU VAT in WooCommerce. Beautifully.', 'eu-vat-for-woocommerce' ),
				'id'       => 'alg_wc_eu_vat_plugin_enabled',
				'default'  => 'yes',
				'type'     => 'checkbox',
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_eu_vat_plugin_options',
			),
		);

		$frontend_settings = array(
			array(
				'title'    => __( 'Frontend Options', 'eu-vat-for-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_eu_vat_frontend_options',
			),
			array(
				'title'    => __( 'Field label', 'eu-vat-for-woocommerce' ),
				'desc_tip' => __( 'Label visible to the customer.', 'eu-vat-for-woocommerce' ),
				'id'       => 'alg_wc_eu_vat_field_label',
				'default'  => __( 'EU VAT Number', 'eu-vat-for-woocommerce' ),
				'type'     => 'text',
				'css'      => 'width:100%;',
			),
			array(
				'title'    => __( 'Placeholder', 'eu-vat-for-woocommerce' ),
				'desc_tip' => __( 'Placeholder visible to the customer.', 'eu-vat-for-woocommerce' ),
				'id'       => 'alg_wc_eu_vat_field_placeholder',
				'default'  => __( 'EU VAT Number', 'eu-vat-for-woocommerce' ),
				'type'     => 'text',
				'css'      => 'width:100%;',
			),
			array(
				'title'    => __( 'Description', 'eu-vat-for-woocommerce' ),
				'desc_tip' => __( 'Description visible to the customer.', 'eu-vat-for-woocommerce' ),
				'id'       => 'alg_wc_eu_vat_field_description',
				'default'  => '',
				'type'     => 'text',
				'css'      => 'width:100%;',
			),
			array(
				'title'    => __( 'Required', 'eu-vat-for-woocommerce' ),
				'desc_tip' => __( 'Sets if EU VAT field is required on checkout.', 'eu-vat-for-woocommerce' ),
				'desc'     => __( 'Yes', 'eu-vat-for-woocommerce' ),
				'id'       => 'alg_wc_eu_vat_field_required',
				'default'  => 'no',
				'type'     => 'checkbox',
			),
			array(
				'title'    => __( 'Clear', 'eu-vat-for-woocommerce' ),
				'desc_tip' => __( 'CSS clear option.', 'eu-vat-for-woocommerce' ),
				'desc'     => __( 'Yes', 'eu-vat-for-woocommerce' ),
				'id'       => 'alg_wc_eu_vat_field_clear',
				'default'  => 'yes',
				'type'     => 'checkbox',
			),
			array(
				'title'    => __( 'CSS class', 'eu-vat-for-woocommerce' ),
				'desc_tip' => __( 'CSS class option.', 'eu-vat-for-woocommerce' ),
				'id'       => 'alg_wc_eu_vat_field_class',
				'default'  => 'form-row-wide',
				'type'     => 'select',
				'class'    => 'wc-enhanced-select',
				'options'  => array(
					'form-row-wide'  => __( 'Wide', 'eu-vat-for-woocommerce' ),
					'form-row-first' => __( 'First', 'eu-vat-for-woocommerce' ),
					'form-row-last'  => __( 'Last', 'eu-vat-for-woocommerce' ),
				),
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_eu_vat_frontend_options',
			),
		);

		$validation_settings = array(
			array(
				'title'    => __( 'Validation', 'eu-vat-for-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_eu_vat_validation_options',
			),
			array(
				'title'    => __( 'Validate', 'eu-vat-for-woocommerce' ),
				'desc_tip' => __( 'Enabled/disables EU VAT validation.', 'eu-vat-for-woocommerce' ),
				'desc'     => __( 'Yes', 'eu-vat-for-woocommerce' ),
				'id'       => 'alg_wc_eu_vat_validate',
				'default'  => 'yes',
				'type'     => 'checkbox',
			),
			array(
				'desc'     => __( 'Message on not valid', 'eu-vat-for-woocommerce' ),
				'desc_tip' => __( 'Message will be displayed, when customer tries to checkout with invalid VAT number ("Validate" option must be enabled).', 'eu-vat-for-woocommerce' ),
				'id'       => 'alg_wc_eu_vat_not_valid_message',
				'default'  => __( '<strong>EU VAT Number</strong> is not valid.', 'eu-vat-for-woocommerce' ),
				'type'     => 'textarea',
				'css'      => 'width:100%;',
			),
			array(
				'title'    => __( 'First validation method', 'eu-vat-for-woocommerce' ),
				'desc_tip' => __( 'Change this if you are having issues when validating VAT. This only selects first method to try - if not succeeded, remaining methods will be used for validation.', 'eu-vat-for-woocommerce' ),
				'id'       => 'alg_wc_eu_vat_first_method',
				'default'  => 'soap',
				'type'     => 'select',
				'class'    => 'wc-enhanced-select',
				'options'  => array(
					'soap'              => __( 'SOAP', 'eu-vat-for-woocommerce' ),
					'curl'              => __( 'cURL', 'eu-vat-for-woocommerce' ),
					'file_get_contents' => __( 'Simple', 'eu-vat-for-woocommerce' ),
				),
			),
			array(
				'title'    => __( 'Exempt VAT for valid numbers', 'eu-vat-for-woocommerce' ),
				'desc_tip' => __( 'Enables/disabled VAT exemption.', 'eu-vat-for-woocommerce' ),
				'desc'     => __( 'Yes', 'eu-vat-for-woocommerce' ),
				'id'       => 'alg_wc_eu_vat_disable_for_valid',
				'default'  => 'yes',
				'type'     => 'checkbox',
			),
			array(
				'title'    => __( 'Preserve VAT in base country', 'eu-vat-for-woocommerce' ),
				'desc_tip' => sprintf( __( 'This will validate the VAT, but won\'t exempt VAT for base country VAT numbers. Base (i.e. store) country is set in %s.', 'eu-vat-for-woocommerce' ),
					'<a href="' . admin_url( 'admin.php?page=wc-settings&tab=general' ) . '">' . __( 'WooCommerce > Settings > General', 'eu-vat-for-woocommerce' ) . '</a>' ) .
					apply_filters( 'alg_wc_eu_vat_option', '<br>' . sprintf( __( 'You will need %s plugin to enable this option.', 'eu-vat-for-woocommerce' ),
						'<a target="_blank" href="https://wpcodefactory.com/item/eu-vat-for-woocommerce/">' . __( 'EU VAT for WooCommerce Pro', 'eu-vat-for-woocommerce' ) . '</a>' ),
						'settings' ),
				'desc'     => __( 'Yes', 'eu-vat-for-woocommerce' ),
				'id'       => 'alg_wc_eu_vat_preserve_in_base_country',
				'default'  => 'no',
				'type'     => 'checkbox',
				'custom_attributes' => apply_filters( 'alg_wc_eu_vat_option', array( 'disabled' => 'disabled' ), 'settings' ),
			),
			array(
				'title'    => __( 'Check for IP location country', 'eu-vat-for-woocommerce' ),
				'desc_tip' => __( 'This will check if customer\'s country (located by customer\'s IP) matches the country in entered VAT number.', 'eu-vat-for-woocommerce' ) .
					apply_filters( 'alg_wc_eu_vat_option', '<br>' . sprintf( __( 'You will need %s plugin to enable this option.', 'eu-vat-for-woocommerce' ),
						'<a target="_blank" href="https://wpcodefactory.com/item/eu-vat-for-woocommerce/">' . __( 'EU VAT for WooCommerce Pro', 'eu-vat-for-woocommerce' ) . '</a>' ),
						'settings' ),
				'desc'     => __( 'Yes', 'eu-vat-for-woocommerce' ),
				'id'       => 'alg_wc_eu_vat_check_ip_location_country',
				'default'  => 'no',
				'type'     => 'checkbox',
				'custom_attributes' => apply_filters( 'alg_wc_eu_vat_option', array( 'disabled' => 'disabled' ), 'settings' ),
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_eu_vat_validation_options',
			),
		);

		$messages_settings = array(
			array(
				'title'    => __( 'Progress Messages', 'eu-vat-for-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_eu_vat_messages_options',
			),
			array(
				'title'    => __( 'Add progress messages', 'eu-vat-for-woocommerce' ),
				'desc_tip' => __( 'Enabled/disables progress messages on checkout.', 'eu-vat-for-woocommerce' ),
				'desc'     => __( 'Add', 'eu-vat-for-woocommerce' ),
				'id'       => 'alg_wc_eu_vat_add_progress_text',
				'default'  => 'no',
				'type'     => 'checkbox',
			),
			array(
				'title'    => __( 'Validating', 'eu-vat-for-woocommerce' ),
				'desc_tip' => __( 'Message when validation is in progress.', 'eu-vat-for-woocommerce' ),
				'id'       => 'alg_wc_eu_vat_progress_text_validating',
				'default'  => __( 'Validating VAT. Please wait...', 'eu-vat-for-woocommerce' ),
				'type'     => 'text',
				'css'      => 'width:100%;',
			),
			array(
				'title'    => __( 'Valid', 'eu-vat-for-woocommerce' ),
				'desc_tip' => __( 'Message on valid VAT.', 'eu-vat-for-woocommerce' ),
				'id'       => 'alg_wc_eu_vat_progress_text_valid',
				'default'  => __( 'VAT is valid.', 'eu-vat-for-woocommerce' ),
				'type'     => 'text',
				'css'      => 'width:100%;',
			),
			array(
				'title'    => __( 'Not valid', 'eu-vat-for-woocommerce' ),
				'desc_tip' => __( 'Message on invalid VAT.', 'eu-vat-for-woocommerce' ),
				'id'       => 'alg_wc_eu_vat_progress_text_not_valid',
				'default'  => __( 'VAT is not valid.', 'eu-vat-for-woocommerce' ),
				'type'     => 'text',
				'css'      => 'width:100%;',
			),
			array(
				'title'    => __( 'Validation failed', 'eu-vat-for-woocommerce' ),
				'desc_tip' => __( 'Message on VAT validation server timeout etc.', 'eu-vat-for-woocommerce' ),
				'id'       => 'alg_wc_eu_vat_progress_text_validation_failed',
				'default'  => __( 'Validation failed. Please try again.', 'eu-vat-for-woocommerce' ),
				'type'     => 'text',
				'css'      => 'width:100%;',
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_eu_vat_messages_options',
			),
		);

		$display_settings = array(
			array(
				'title'    => __( 'Display Options', 'eu-vat-for-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_eu_vat_display_options',
			),
			array(
				'title'    => __( 'Display', 'eu-vat-for-woocommerce' ),
				'id'       => 'alg_wc_eu_vat_display_position',
				'default'  => 'after_order_table',
				'type'     => 'select',
				'class'    => 'wc-enhanced-select',
				'options'  => array(
					'after_order_table'  => __( 'After order table', 'eu-vat-for-woocommerce' ),
					'in_billing_address' => __( 'In billing address', 'eu-vat-for-woocommerce' ),
				),
			),
			array(
				'title'    => __( 'EU VAT number summary admin meta box', 'eu-vat-for-woocommerce' ),
				'desc_tip' => __( 'Adds EU VAT number summary meta box to admin order edit page.', 'eu-vat-for-woocommerce' ),
				'desc'     => __( 'Add', 'eu-vat-for-woocommerce' ),
				'id'       => 'alg_wc_eu_vat_add_order_edit_metabox',
				'default'  => 'no',
				'type'     => 'checkbox',
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_eu_vat_display_options',
			),
		);

		$advanced_settings = array(
			array(
				'title'    => __( 'Advanced Options', 'eu-vat-for-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_eu_vat_advanced_options',
			),
			array(
				'title'    => __( 'Skip VAT validation for selected countries', 'eu-vat-for-woocommerce' ),
				'desc_tip' => __( 'List all countries you want VAT validation to be skipped for (i.e. VAT always valid). Ignored if empty.', 'eu-vat-for-woocommerce' ),
				'desc'     => sprintf( __( 'Enter country codes as comma separated list, e.g. %s.', 'eu-vat-for-woocommerce' ), '<code>IT,NL</code>' ),
				'id'       => 'alg_wc_eu_vat_advanced_skip_countries',
				'default'  => '',
				'type'     => 'text',
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_eu_vat_advanced_options',
			),
		);

		return array_merge( $plugin_settings, $frontend_settings, $validation_settings, $messages_settings, $display_settings, $advanced_settings, $settings );
	}

}

endif;

return new Alg_WC_EU_VAT_Settings_General();
